@@ -29,8 +29,9 @@
 #'   \code{\link[ggplot2]{layer}} for more details.
 #' @param na.rm	a logical indicating whether NA values should be stripped before
 #'   the computation proceeds.
-#' @param pool.along character, one of "none", "x" or "y", indicating which
-#'   quadrants to pool to calculate counts by pair of quadrants.
+#' @param pool.along character, one of \code{"none"}, \code{"x"} or \code{"y"},
+#'   indicating which quadrants to pool to calculate counts by pair of
+#'   quadrants.
 #' @param xintercept,yintercept numeric vectors the coordinates of the origin of the
 #'   quadrants.
 #'
@@ -68,16 +69,22 @@
 #'   geom_point()
 #'
 #' ggplot(my.data, aes(x, y)) +
-#'   geom_quadrant_lines(xintercept = 50, yintercept = 10, colour = "blue") +
+#'   geom_quadrant_lines(xintercept = 50,
+#'                       yintercept = 10,
+#'                       colour = "blue") +
 #'   geom_point()
 #'
 #' ggplot(my.data, aes(x, y)) +
-#'   geom_quadrant_lines(xintercept = 50, pool.along = "y", colour = "blue") +
+#'   geom_quadrant_lines(xintercept = 50,
+#'                       pool.along = "y",
+#'                       colour = "blue") +
 #'   geom_point()
 #'
 #' ggplot(my.data, aes(x, y)) +
-#'   geom_vhlines(xintercept = c(25, 50, 75), yintercept = 10 ,
-#'                linetype = "dotted", colour = "red") +
+#'   geom_vhlines(xintercept = c(25, 50, 75),
+#'                yintercept = 10 ,
+#'                linetype = "dotted",
+#'                colour = "red") +
 #'   geom_point() +
 #'   theme_bw()
 #'
@@ -103,7 +110,7 @@ geom_quadrant_lines <- function(mapping = NULL,
                             yintercept = yintercept)
     show.legend <- FALSE
   } else if (xor(missing(xintercept), missing(yintercept))) {
-    stop("Arguments should be passed either to none or both of 'xintrecept' and 'yintercept'")
+    stop("Missing 'xintercept' and 'yintercept'")
   }
 
   ggplot2::layer(
@@ -129,7 +136,7 @@ geom_quadrant_lines <- function(mapping = NULL,
 GeomQuadrantLines <-
   ggplot2::ggproto(
     "GeomQuadrantLines", Geom,
-    draw_panel = function(data, panel_params, coord, pool.along = "none") {
+    draw_panel = function(data, panel_params, coord, pool.along = "none", lineend = "butt") {
       ranges <- coord$backtransform_range(panel_params)
       data.hline <- data.vline <- data
 
@@ -160,18 +167,21 @@ GeomQuadrantLines <-
                      data[NULL, ]
       )
 
-      ggplot2::GeomSegment$draw_panel(unique(data), panel_params, coord)
+      ggplot2::GeomSegment$draw_panel(unique(data), panel_params, coord, lineend = lineend)
 
     },
 
     default_aes = ggplot2::aes(colour = "black",
-                               size = 0.5,
+                               size = 0.5, # ggplot2 (<= 3.3.6)
+                               linewidth = 0.5, # ggplot2 (> 3.3.6)
                                linetype = "dashed",
                                alpha = NA),
     required_aes = c("xintercept", "yintercept"),
     non_missing_aes = c("size", "linetype", "colour"),
 
-    draw_key = draw_key_path
+    draw_key = draw_key_path,
+
+    rename_size = TRUE
   )
 
 #' @rdname geom_quadrant_lines
@@ -216,7 +226,7 @@ geom_vhlines <- function(mapping = NULL, data = NULL,
 GeomVHLines <-
   ggplot2::ggproto(
     "GeomVHLines", Geom,
-    draw_panel = function(data, panel_params, coord) {
+    draw_panel = function(data, panel_params, coord, lineend = "butt") {
       ranges <- coord$backtransform_range(panel_params)
       data.hline <- data.vline <- data
 
@@ -232,16 +242,19 @@ GeomVHLines <-
 
       data <- rbind(data.hline, data.vline)
 
-      ggplot2::GeomSegment$draw_panel(unique(data), panel_params, coord)
+      ggplot2::GeomSegment$draw_panel(unique(data), panel_params, coord, lineend = lineend)
 
     },
 
     default_aes = ggplot2::aes(colour = "black",
-                               size = 0.5,
+                               size = 0.5, # ggplot2 (<= 3.3.6)
+                               linewidth = 0.5, # ggplot2 (> 3.3.6)
                                linetype = 1,
                                alpha = NA),
     required_aes = c("xintercept", "yintercept"),
     non_missing_aes = c("size", "linetype", "colour"),
 
-    draw_key = draw_key_path
+    draw_key = draw_key_path,
+
+    rename_size = TRUE
   )
